function [error] = writeAsciiTsg( hMainFig, filename)
%
% Function to write the TSG data in an ASCII file
%
% Input
% -----
% hMainFig ............ Handel to the main user interface
% filename ........... Data filename
%
% Output
% ------
% error .............. 1: OK - -1 : no ouput
%

% initialise
% ----------
error = -1;

PARA = { 'CNDC'; 'CNDC_CAL'; ...
         'SSPS'; 'SSPS_QC'; 'SSPS_CAL';...
         'SSPS_ADJUSTED'; 'SSPS_ADJUSTED_QC'; 'SSPS_ADJUSTED_ERROR'; ...
         'SSJT'; 'SSJT_QC'; 'SSJT_CAL';...
         'SSJT_ADJUSTED'; 'SSJT_ADJUSTED_QC'; 'SSJT_ADJUSTED_ERROR'; ...
         'SSTP'; 'SSTP_QC'; 'SSTP_CAL';...
         'SSTP_ADJUSTED'; 'SSTP_ADJUSTED_QC'; 'SSTP_ADJUSTED_ERROR'};

% Choose parameters to export
% ---------------------------
[colParaNo, choice] = exportParameterChoice( PARA );

if choice

  % Open the file
  % -------------
  fid = fopen( filename, 'wt' );

  if fid ~= -1

    % Display write file info on console
    % ---------------------------------
    fprintf('\nWRITE_TXT_FILE\n'); tic;

    % Display more info about write file on console
    % ---------------------------------------------
    fprintf('...writing %s : ', filename);

    % Get the data from the application GUI
    % -------------------------------------
    tsg = getappdata( hMainFig, 'tsg_data');

    nbRecords = length( tsg.DAYD );
    if nbRecords ~= 0

      [year, month, day, hour, min, sec] = datevec( tsg.DAYD );
      tsg_data = [year month day hour min fix(sec) tsg.LATX tsg.LONX ];
      header = 'yyyy mm dd hh mi ss LATX LONX';
      format = '%04d %02d %02d %02d %02d %02d %12.7f %12.7f';

      for i = 1 : length(colParaNo)
        para = PARA{colParaNo(i)};

        if isempty(tsg.(para))
          tsg.(para) = NaN * ones( size( tsg.DAYD ) );
        end

        if findstr( '_QC', para)
          tsg_data = [tsg_data double(tsg.(para))];
          format   = [format ' %1d'];
        else
          tsg_data = [tsg_data tsg.(para)];
          format   = [format ' %6.3f'];
        end
        header   = [header ' ' para];
        
      end

      % Write some information
      % ----------------------
      if ~isempty( tsg.CYCLE_MESURE )
        fprintf( fid, '%%CYCLE_MESURE %s\n', tsg.CYCLE_MESURE);
      end

      if ~isempty( tsg.PLATFORM_NAME )
        fprintf( fid, '%%PLATFORM_NAME %s\n', tsg.PLATFORM_NAME);
      end

      % Write the file
      % --------------
      fprintf( fid, '%%HEADER %s\n', header);

      fprintf(fid, [format '\n'], tsg_data');

      % Clear the Workspace
      % -------------------
      clear tsgdata

      % Everything OK
      % -------------
      error = 1;

    end

    % Close the file
    % --------------
    fclose( fid );

    % Display time to write file on console
    % -------------------------------------
    t = toc; fprintf('...done (%6.2f sec).\n\n',t);

  end
end
